PAWpySeed: pawpyseed.core.wavefunction.Pseudopotential Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
pawpyseed.core.wavefunction.Pseudopotential Class Reference

## Public Member Functions
def | __init__ (self, data)
def | make_nums (self, numstring)

## Public Attributes
| pswaves
| aewaves
| recipprojs
| realprojs
| nonlocalprojs
| ls
| grid
| aepotential
| aecorecharge
| kinetic
| pspotential
| pscorecharge
| augs
| T
| gradxc
| localpart
| localnum
| coredensity
| atomicdensity
| rmax
| ndata
| projgrid
| step

## Detailed Description

    Contains important attributes from a VASP pseudopotential files. POTCAR
    "settings" can be read from the pymatgen POTCAR object

    If you use pymatgen, you can think of this as correlating with
    the PotcarSingle object.

    Note: for the following attributes, 'index' refers to an energy
    quantum number epsilon and angular momentum quantum number l,
    which define one set consisting of a projector function, all electron
    partial waves, and pseudo partial waves.

    Attributes:
        rmax (np.float64): Maximum radius of the projection operators
        grid (np.array): radial grid on which partial waves are defined
        aepotential (np.array): All electron potential defined radially on grid
        aecorecharge (np.array): All electron core charge defined radially
            on grid (i.e. charge due to core, and not valence, electrons)
        kinetic (np.array): Core kinetic energy density, defined raidally on grid
        pspotential (np.array): pseudopotential defined on grid
        pscorecharge (np.array): pseudo core charge defined on grid
        ls (list): l quantum number for each index
        pswaves (list of np.array): pseudo partial waves for each index
        aewaves (list of np.array): all electron partial waves for each index
        projgrid (np.array): radial grid on which projector functions are defined
        recipprojs (list of np.array): reciprocal space projection operators
            for each index
        realprojs (list of np.array): real space projection operators
            for each index

## Constructor & Destructor Documentation

def pawpyseed.core.wavefunction.Pseudopotential.__init__ | ( |  | self,
|  |  | data
| ) |  |

    Initializer for Pseudopotential.
    Should only be used by CoreRegion.

    Arguments:
        data (str): single-element pseudopotential
    (POTCAR) as a string

## Member Function Documentation

def pawpyseed.core.wavefunction.Pseudopotential.make_nums | ( |  | self,
|  |  | numstring
| ) |  |

## Member Data Documentation

pawpyseed.core.wavefunction.Pseudopotential.aecorecharge

pawpyseed.core.wavefunction.Pseudopotential.aepotential

pawpyseed.core.wavefunction.Pseudopotential.aewaves

pawpyseed.core.wavefunction.Pseudopotential.atomicdensity

pawpyseed.core.wavefunction.Pseudopotential.augs

pawpyseed.core.wavefunction.Pseudopotential.coredensity

pawpyseed.core.wavefunction.Pseudopotential.gradxc

pawpyseed.core.wavefunction.Pseudopotential.grid

pawpyseed.core.wavefunction.Pseudopotential.kinetic

pawpyseed.core.wavefunction.Pseudopotential.localnum

pawpyseed.core.wavefunction.Pseudopotential.localpart

pawpyseed.core.wavefunction.Pseudopotential.ls

pawpyseed.core.wavefunction.Pseudopotential.ndata

pawpyseed.core.wavefunction.Pseudopotential.nonlocalprojs

pawpyseed.core.wavefunction.Pseudopotential.projgrid

pawpyseed.core.wavefunction.Pseudopotential.pscorecharge

pawpyseed.core.wavefunction.Pseudopotential.pspotential

pawpyseed.core.wavefunction.Pseudopotential.pswaves

pawpyseed.core.wavefunction.Pseudopotential.realprojs

pawpyseed.core.wavefunction.Pseudopotential.recipprojs

pawpyseed.core.wavefunction.Pseudopotential.rmax

pawpyseed.core.wavefunction.Pseudopotential.step

pawpyseed.core.wavefunction.Pseudopotential.T

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/wavefunction.py